# This file was generated by Rcpp::compileAttributes
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

add_trie_string <- function(trie, keys, values) {
    invisible(.Call('triebeard_add_trie_string', PACKAGE = 'triebeard', trie, keys, values))
}

add_trie_integer <- function(trie, keys, values) {
    invisible(.Call('triebeard_add_trie_integer', PACKAGE = 'triebeard', trie, keys, values))
}

add_trie_numeric <- function(trie, keys, values) {
    invisible(.Call('triebeard_add_trie_numeric', PACKAGE = 'triebeard', trie, keys, values))
}

add_trie_logical <- function(trie, keys, values) {
    invisible(.Call('triebeard_add_trie_logical', PACKAGE = 'triebeard', trie, keys, values))
}

remove_trie_string <- function(trie, keys) {
    invisible(.Call('triebeard_remove_trie_string', PACKAGE = 'triebeard', trie, keys))
}

remove_trie_integer <- function(trie, keys) {
    invisible(.Call('triebeard_remove_trie_integer', PACKAGE = 'triebeard', trie, keys))
}

remove_trie_numeric <- function(trie, keys) {
    invisible(.Call('triebeard_remove_trie_numeric', PACKAGE = 'triebeard', trie, keys))
}

remove_trie_logical <- function(trie, keys) {
    invisible(.Call('triebeard_remove_trie_logical', PACKAGE = 'triebeard', trie, keys))
}

radix_create_string <- function(keys, values) {
    .Call('triebeard_radix_create_string', PACKAGE = 'triebeard', keys, values)
}

radix_create_integer <- function(keys, values) {
    .Call('triebeard_radix_create_integer', PACKAGE = 'triebeard', keys, values)
}

radix_create_numeric <- function(keys, values) {
    .Call('triebeard_radix_create_numeric', PACKAGE = 'triebeard', keys, values)
}

radix_create_logical <- function(keys, values) {
    .Call('triebeard_radix_create_logical', PACKAGE = 'triebeard', keys, values)
}

get_keys_string <- function(radix) {
    .Call('triebeard_get_keys_string', PACKAGE = 'triebeard', radix)
}

get_keys_integer <- function(radix) {
    .Call('triebeard_get_keys_integer', PACKAGE = 'triebeard', radix)
}

get_keys_numeric <- function(radix) {
    .Call('triebeard_get_keys_numeric', PACKAGE = 'triebeard', radix)
}

get_keys_logical <- function(radix) {
    .Call('triebeard_get_keys_logical', PACKAGE = 'triebeard', radix)
}

get_values_string <- function(radix) {
    .Call('triebeard_get_values_string', PACKAGE = 'triebeard', radix)
}

get_values_integer <- function(radix) {
    .Call('triebeard_get_values_integer', PACKAGE = 'triebeard', radix)
}

get_values_numeric <- function(radix) {
    .Call('triebeard_get_values_numeric', PACKAGE = 'triebeard', radix)
}

get_values_logical <- function(radix) {
    .Call('triebeard_get_values_logical', PACKAGE = 'triebeard', radix)
}

greedy_string <- function(radix, to_match) {
    .Call('triebeard_greedy_string', PACKAGE = 'triebeard', radix, to_match)
}

greedy_integer <- function(radix, to_match) {
    .Call('triebeard_greedy_integer', PACKAGE = 'triebeard', radix, to_match)
}

greedy_numeric <- function(radix, to_match) {
    .Call('triebeard_greedy_numeric', PACKAGE = 'triebeard', radix, to_match)
}

greedy_logical <- function(radix, to_match) {
    .Call('triebeard_greedy_logical', PACKAGE = 'triebeard', radix, to_match)
}

radix_len_string <- function(radix) {
    .Call('triebeard_radix_len_string', PACKAGE = 'triebeard', radix)
}

radix_len_integer <- function(radix) {
    .Call('triebeard_radix_len_integer', PACKAGE = 'triebeard', radix)
}

radix_len_numeric <- function(radix) {
    .Call('triebeard_radix_len_numeric', PACKAGE = 'triebeard', radix)
}

radix_len_logical <- function(radix) {
    .Call('triebeard_radix_len_logical', PACKAGE = 'triebeard', radix)
}

longest_string <- function(radix, to_match) {
    .Call('triebeard_longest_string', PACKAGE = 'triebeard', radix, to_match)
}

longest_integer <- function(radix, to_match) {
    .Call('triebeard_longest_integer', PACKAGE = 'triebeard', radix, to_match)
}

longest_numeric <- function(radix, to_match) {
    .Call('triebeard_longest_numeric', PACKAGE = 'triebeard', radix, to_match)
}

longest_logical <- function(radix, to_match) {
    .Call('triebeard_longest_logical', PACKAGE = 'triebeard', radix, to_match)
}

prefix_string <- function(radix, to_match) {
    .Call('triebeard_prefix_string', PACKAGE = 'triebeard', radix, to_match)
}

prefix_integer <- function(radix, to_match) {
    .Call('triebeard_prefix_integer', PACKAGE = 'triebeard', radix, to_match)
}

prefix_numeric <- function(radix, to_match) {
    .Call('triebeard_prefix_numeric', PACKAGE = 'triebeard', radix, to_match)
}

prefix_logical <- function(radix, to_match) {
    .Call('triebeard_prefix_logical', PACKAGE = 'triebeard', radix, to_match)
}

trie_str_string <- function(radix) {
    invisible(.Call('triebeard_trie_str_string', PACKAGE = 'triebeard', radix))
}

trie_str_integer <- function(radix) {
    invisible(.Call('triebeard_trie_str_integer', PACKAGE = 'triebeard', radix))
}

trie_str_numeric <- function(radix) {
    invisible(.Call('triebeard_trie_str_numeric', PACKAGE = 'triebeard', radix))
}

trie_str_logical <- function(radix) {
    invisible(.Call('triebeard_trie_str_logical', PACKAGE = 'triebeard', radix))
}

